==> GeneSpring_1.0.1.tar.gz: GeneSpring/man/GSload.int.Rd <==
\name{GSload.int}
\alias{GSload.int}
\alias{GSload.intBC}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Read GeneSpring Experiment Interpretation from file}
\description{
A GeneSpring Experiment Interpretation is read in, usually from a file,
but a connection object (like \code{stdin()}) can also be passed.
The return value can either be an object of class \code{GSint} or
BioConductor \code{exprSet} representing the Experiment Interpretation
from GeneSpring.
}
\usage{
gs.int <- GSload.int(filename = "GS_R_in.txt")
expr.set <- GSload.intBC(filename = "GS_R_in.txt", what = "nor")
}
%- maybe also 'usage' for other objects documented here.

\arguments{

\item{filename}{Name of the file containing the GeneSpring Experiment Interpretation. Can also be a connection object.}
\item{what}{ For \code{GSload.intBC()} only. Indicates what data from the
GeneSpring Experiment Interpretation should be used.
Valid values for \code{what} can be \code{nor} and \code{raw}, representing
Normalized or Raw expression values. The Control values cannot be used.}

}
\details{
A GeneSpring Experiment INTERPRETATION is quite distinct from a GeneSpring
Experiment. See \code{GSload.exp()} for more information on GeneSpring Experiments.

A GeneSpring Experiment Interpretation can consist of a maximum of three sets
of six (eighteen total) columns for each condition;
The sets can be the Normalized, Raw and Control sets and each set can consists of
the Average, Min, Max, Standard error, Standard Deviation and Number of samples per condition.
The \code{GSint} class will be populated based on the names of the columns.
The column names can be any of the following:

x.AVERAGE, x.MIN, x.MAX, x.STDERR, x.STDDEV, x.N

Where x can be either N, C or R, representing Normalized, Control and Raw data
If there is more than one conditions, each consecutive set is numerbed by adding a
number to the end of the name
The first column does not have a number and the second will start numbering at 1

If there is more than one type (i.e if there is both Normalized and Raw data),
Each value type (AVERAGE, MIN, STDEV etc) is listed first for each data type

Examples:

N.AVERAGE, R.AVERAGE, N.MIN, R.MIN, N.AVERAGE.1, R.AVERAGE.1, N.MIN.1 etc.

Since teh GeneSpring user can determine what data to send to the external program,
it is up to the R programmer to determine which columns contains what type of data.

}
\value{
The return value depends on which fucntion was called.
The \code{GSload.int} function returns a object of class \code{GSint}.
The \code{GSload.intBC} function returns a BioConductor object of class \code{exprSet}.
See the documentation on \code{GSint} and \code{exprSet} for more information.
}
\references{ 

For more information on using GeneSpring with R see
\url{http://www.silicongenetics.com/cgi/SiG.cgi/Support/GeneSpring/GSnotes/R.smf}
}
\author{ 
   Thon de Boer, Silicon Genetics, Redwood city, CA, USA \email{thon@silicongenetics.com}

}
\note{ This and any other functions in the GeneSpring package are only useful,
when using Silicon Genetics Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.exp}},
\code{\link{GSsave.exp}}
\code{\link{GSint2BC}},
\code{\link{BC2GSint}}
}
\examples{

}
\keyword{ IO }% at least one, from doc/KEYWORDS

==> GeneSpring_2.4.0.tar.gz: GeneSpring/man/GSload.int.Rd <==
\name{GSload.int}
\alias{GSload.int}
\alias{GSload.intBC}
%- Also NEED an '\alias' for EACH other topic documented here.
\title{Read GeneSpring Experiment Interpretation from file}
\description{
A GeneSpring Experiment Interpretation is read in, usually from a file,
but a connection object (like \code{stdin()}) can also be passed.
The return value can either be an object of class \code{GSint} or
BioConductor \code{exprSet} representing the Experiment Interpretation
from GeneSpring.
}
\usage{
gs.int <- GSload.int(filename = "GS_R_in.txt")
expr.set <- GSload.intBC(filename = "GS_R_in.txt", what = "nor")
}
%- maybe also 'usage' for other objects documented here.

\arguments{

\item{filename}{Name of the file containing the GeneSpring Experiment Interpretation. Can also be a connection object.}
\item{what}{ For \code{GSload.intBC()} only. Indicates what data from the
GeneSpring Experiment Interpretation should be used.
Valid values for \code{what} can be \code{nor} and \code{raw}, representing
Normalized or Raw expression values. The Control values cannot be used.}

}
\details{
A GeneSpring Experiment INTERPRETATION is quite distinct from a GeneSpring
Experiment. See \code{GSload.exp()} for more information on GeneSpring Experiments.

A GeneSpring Experiment Interpretation can consist of a maximum of three sets
of six (eighteen total) columns for each condition;
The sets can be the Normalized, Raw and Control sets and each set can consists of
the Average, Min, Max, Standard error, Standard Deviation and Number of samples per condition.
The \code{GSint} class will be populated based on the names of the columns.
The column names can be any of the following:

x.AVERAGE, x.MIN, x.MAX, x.STDERR, x.STDDEV, x.N

Where x can be either N, C or R, representing Normalized, Control and Raw data
If there is more than one conditions, each consecutive set is numerbed by adding a
number to the end of the name
The first column does not have a number and the second will start numbering at 1

If there is more than one type (i.e if there is both Normalized and Raw data),
Each value type (AVERAGE, MIN, STDEV etc) is listed first for each data type

Examples:

N.AVERAGE, R.AVERAGE, N.MIN, R.MIN, N.AVERAGE.1, R.AVERAGE.1, N.MIN.1 etc.

Since teh GeneSpring user can determine what data to send to the external program,
it is up to the R programmer to determine which columns contains what type of data.

}
\value{
The return value depends on which fucntion was called.
The \code{GSload.int} function returns a object of class \code{GSint}.
The \code{GSload.intBC} function returns a BioConductor object of class \code{exprSet}.
See the documentation on \code{GSint} and \code{exprSet} for more information.
}
\references{ 

For more information on using GeneSpring with R see
\url{http://www.chem.agilent.com/scripts/generic.asp?lpage=34733}
}
\author{ 
   Thon de Boer, Agilent Technologies, Santa Clara, CA, USA \email{thon\_deboer@agilent.com}
}
\note{ This and any other functions in the GeneSpring package are only useful,
when using Agilent Technologies Gene Expression software GeneSpring.
}

\seealso{
\code{\link{GSload.exp}},
\code{\link{GSsave.exp}}
\code{\link{GSint2BC}},
\code{\link{BC2GSint}}
}
\examples{

}
\keyword{ IO }% at least one, from doc/KEYWORDS
